"""
Base ETI class
"""
class ExternalTaskInterface(object):
    """
    The External Task Interface base class. It prepares, executes, recovers,
    and cleans all files and parameters pertaining to any external task
    that interfaces with this package.
    """
    def __init__(self):
        self.param_objs = []
        self.file_objs = []
        self._set_name(__name__)

    def _format_log(self, string):
        return "{0} {1}".format(self._eti_name, string)

    def _set_name_flag(self, flag):
        if not hasattr(self, '_set_eti_name'):
            self._set_eti_name = flag

    def _set_taskname(self):
        if self._eti_name.lower().endswith("eti"):
            self._taskname = self._eti_name[:-3]
        else:
            self._taskname = self._eti_name

    def _set_name(self, name):
        if not hasattr(self, '_set_eti_name'):
            self._eti_name = name.split(".")[-1]
            self._set_name_flag(flag=True)
            self._set_taskname()

    def run(self):
        self.prepare()
        self.execute()
        self.recover()
        self.clean()

    def add_param(self, param):
        self.param_objs.append(param)

    def add_file(self, file_object):
        self.file_objs.append(file_object)

    def prepare(self):
        for par in self.param_objs:
            par.prepare()
        for fil in self.file_objs:
            fil.prepare()

    def execute(self):
        pass

    def recover(self):
        for par in self.param_objs:
            par.recover()
        for fil in self.file_objs:
            fil.recover()

    def clean(self):
        for par in self.param_objs:
            par.clean()
        for fil in self.file_objs:
            fil.clean()